:mod:`art.estimators.classification.scikitlearn`
================================================
.. automodule:: art.estimators.classification.scikitlearn

Base Class Scikit-learn
-----------------------
.. autoclass:: ScikitlearnClassifier
   :members:

Scikit-learn DecisionTreeClassifier Classifier
----------------------------------------------
.. autoclass:: ScikitlearnDecisionTreeClassifier
   :members:
   :special-members: __init__
   :inherited-members:

Scikit-learn ExtraTreeClassifier Classifier
-------------------------------------------
.. autoclass:: ScikitlearnExtraTreeClassifier
   :members:
   :special-members: __init__
   :inherited-members:

Scikit-learn AdaBoostClassifier Classifier
------------------------------------------
.. autoclass:: ScikitlearnAdaBoostClassifier
   :members:
   :special-members: __init__
   :inherited-members:

Scikit-learn BaggingClassifier Classifier
-----------------------------------------
.. autoclass:: ScikitlearnBaggingClassifier
   :members:
   :special-members: __init__
   :inherited-members:

Scikit-learn ExtraTreesClassifier Classifier
--------------------------------------------
.. autoclass:: ScikitlearnExtraTreesClassifier
   :members:
   :special-members: __init__
   :inherited-members:

Scikit-learn GradientBoostingClassifier Classifier
--------------------------------------------------
.. autoclass:: ScikitlearnGradientBoostingClassifier
   :members:
   :special-members: __init__
   :inherited-members:

Scikit-learn RandomForestClassifier Classifier
----------------------------------------------
.. autoclass:: ScikitlearnRandomForestClassifier
   :members:
   :special-members: __init__
   :inherited-members:

Scikit-learn LogisticRegression Classifier
------------------------------------------
.. autoclass:: ScikitlearnLogisticRegression
   :members:
   :special-members: __init__
   :inherited-members:

Scikit-learn SVC Classifier
---------------------------
.. autoclass:: ScikitlearnSVC
   :members:
   :special-members: __init__
   :inherited-members:
